@@ -1,6 +1,6 @@
 package Net::Google::CivicInformation::Representatives;
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 use strict;
 use warnings;
@@ -17,6 +17,10 @@ use namespace::clean;
 
 extends 'Net::Google::CivicInformation';
 
+BEGIN {
+    warn 'Net::Google::CivicInformation::Representatives is deprecated (Google terminated the API) and should no longer be used';
+}
+
 ##
 sub _build__api_url {
     return 'representatives';
@@ -84,13 +88,18 @@ __END__
 
 =head1 VERSION
 
-version 0.03
+version 0.04
 
 =encoding utf8
 
 =head1 NAME
 
-Net::Google::CivicInformation::Representatives - All elected representatives for US addresses
+DEPRECATED: Net::Google::CivicInformation::Representatives - All elected representatives for US addresses
+
+=head1 DESCRIPTION
+
+  DEPRECATED: In April 2025 Google discontinued the API that this module depended on. 
+  The module should no longer be used, and cannot return any data.
 
 =head1 SYNOPSIS
 
@@ -114,15 +123,13 @@ Net::Google::CivicInformation::Representatives - All elected representatives for
 Requires an address string as the only argument. Returns an object providing methods
 to access the reponse data, or else a method C<error> containing MORE DOC NEEDED HERE.
 
-=cut
-
 =head1 AUTHOR
 
 Nick Tonkin <tonkin@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021 by Nick Tonkin.
+This software is copyright (c) 2025 by Nick Tonkin.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
